@@ -43,8 +43,8 @@ if(is.null(options)){options <- "best.keys"}
     ncrit <-length(criteria)
   if(isCorrelation(data)) {raw <- FALSE
     R <-data[vars,vars]
-  }  else {raw<- TRUE
-     data <- data[vars ]  #select just the variables in the model
+  }  else {raw <- TRUE
+     data <- data[,vars, drop=FALSE ]  #select just the variables in the model
   
     R <- cor(data,use="pairwise")
     }  #this is a matrix of the (criteria + predictors)
@@ -71,10 +71,10 @@ if(is.null(options)){options <- "best.keys"}
      names(cv) <- criteria
 
      #now do the raw correlation approach
-    if(raw) {x.data <- scale(data[predictors])
+    if(raw) {x.data <- scale(data[,predictors])
    
      pred <- matrixMult.na(x.data,wt,scale = FALSE) 
-     item.R <- cor(pred,data[criteria],use="pairwise")
+     item.R <- cor(pred,data[,criteria],use="pairwise")
       colnames(Mij) <- rownames(Mij)<-colnames(item.R)
      cv.items <-diag(item.R)
      crossValid <- data.frame(items = cv.items, mat = cv)} else {CrossValid <- cv}
@@ -90,7 +90,7 @@ matPlot <- function(x, type = "b", minlength=6, xlas=0,legend=NULL,lab=NULL,pch=
      rownames(x)<- abbreviate(rownames(x),minlength=minlength)
       nvar <- NCOL(x)
        if(missing(pch)) pch <- seq(15,(15+nvar))
-    matplot(x,type=type,xaxt="n",pch=pch,col=col,...)
+    matplot(x,type=type,xaxt="n",pch=pch,col=col,lty=lty,...)
     #now add the labels 
      at1 <- (1:nrow(x))
      labx <- (rownames(x))
@@ -105,3 +105,53 @@ matPlot <- function(x, type = "b", minlength=6, xlas=0,legend=NULL,lab=NULL,pch=
      }
      
  #Fixed 9/9/20 to handle case of single criterion (by using drop=FALSE in appropriate places)
+ 
+ #added 8/1/22 to do multiple cross validations using bootstrap resampling
+ crossValidationBoot <- function(y,x,data,n.iter=100) {
+ #allow formulat input
+  #first, see if they are in formula mode  
+  orig.y <- z <-  NULL
+  
+   if(inherits(y,"formula")) {
+   orig.y <- y 
+   ps <- fparse(y)
+   y <- ps$y
+   x <- ps$x
+   med <- ps$m #but, mediation is not done here, so we just add this to x
+  # if(!is.null(med)) x <- c(x,med)   #not  necessary, because we automatically put this in
+   prod <- ps$prod
+   z <- ps$z   #do we have any variable to partial out
+   ex <- ps$ex
+   if(!is.null(ex))  message("I am sorry, cross validation of product terms has not been implemented")
+}
+ 
+ summary <- matrix(NA,nrow=n.iter,ncol=2*length(y))
+ coeff <- list()
+ yn <- colnames(data[y])
+ cl <- match.call()
+ n.obs <- NROW(data)
+ for (i in 1:n.iter) {ss <-  sample(n.obs,n.obs,replace=TRUE)  #the bootstrap sample
+   if(!is.null(orig.y)) {y <- orig.y}
+     model <- setCor(y=y,x=x,data=data[ss,],  plot=FALSE)
+     if(!is.null(z)) {
+     
+         rownames(model$coefficients) <- gsub("\\*","",rownames(model$coefficients))
+         colnames(model$coefficients) <- gsub("\\*","",colnames(model$coefficients))}
+     cross <- crossValidation(model,data=data[-ss,])   #the hold out sample
+     summary[i,] <- c(model$R,diag(cross$item.R))
+     coeff[[i]] <- model$coefficients
+    }
+    if(length(y) >1 ) {colnames(summary) <- c(paste0("Derivation-",yn),paste0("Cross-",yn))} else {
+    colnames(summary) <- c("Derivation", "Cross.validation")}
+    
+
+    coeff <- matrix(unlist(coeff), ncol=length(model$coefficients),byrow=TRUE)
+    colnames(coeff) <- rownames(model$coefficients)
+    result <- list(mean.fit = colMeans(summary),mean.coeff=colMeans(coeff), trials = summary, coefficients = coeff,Call=cl)
+    class(result) <- c("psych","crossV")
+  return(result)
+ }
+ 
+ 
+ 
+
