@@ -1,7 +1,12 @@
-"factor.scores" <- function(x,f,Phi=NULL,method=c("Thurstone","tenBerge","Anderson","Bartlett","Harman","components"),rho=NULL,impute="none") {
+"factor.scores" <- function(x,f,Phi=NULL,method=c("Thurstone","tenBerge","Anderson","Bartlett","Harman","components"),rho=NULL,missing=FALSE,impute="none") {
+#the normal case is f is the structure matrix and Phi is not specified
+#Note that the Grice formulas distinguish between Pattern and Structure matrices
+#I need to confirm that I am doing this
+
     if(length(method) > 1) method <- "tenBerge"   #the default
     if(method=="regression") method <- "Thurstone"
-    if(length(class(f)) >1) { if(class(f)[2] =="irt.fa" ) f <- f$fa  }
+    if(method %in% c("tenberge", "Tenberge","tenBerge","TenBerge")) method <- "tenBerge"
+    if(length(class(f)) > 1) { if(inherits(f[2] ,"irt.fa" )) f <- f$fa  }
     
      if(!is.matrix(f)) {Phi <- f$Phi
      f <- loadings(f)
@@ -15,18 +20,19 @@
          if(!is.null(rho)) {r <- rho } else {
           r <- cor(x,use="pairwise") #find the correlation matrix from the data
       }}
-       
+      
+      S <- f %*% Phi   #the Structure matrix 
    switch(method,   
-    "Thurstone" = { w <- try(solve(r,f),silent=TRUE )  #these are the factor weights
-     	if(class(w)=="try-error") {message("In factor.scores, the correlation matrix is singular, an approximation is used")
-               r <- cor.smooth(r)}
+    "Thurstone" = { w <- try(solve(r,S),silent=TRUE )  #these are the factor weights (see Grice eq. 5)
+     	if(inherits(w,"try-error")) {message("In factor.scores, the correlation matrix is singular, the pseudo inverse is  used")
+              # r <- cor.smooth(r)
+              w  <- Pinv(r) %*% S }
         
-      w <- try(solve(r,f),silent=TRUE)
-      if(class(w)=="try-error") {message("I was unable to calculate the factor score weights, factor loadings used instead")
+      w <- try(solve(r,S),silent=TRUE)
+      if(inherits(w,"try-error")) {message("I was unable to calculate the factor score weights, factor loadings used instead")
                w <- f}
       colnames(w) <- colnames(f)
-       rownames(w) <- rownames(f)
-
+      rownames(w) <- rownames(f)
        }, 
       
   "tenBerge" = { #Following Grice equation 8 to estimate scores for oblique solutions (with a correction to the second line where r should r.inv
@@ -35,7 +41,7 @@
        
         r <- cor.smooth(r)
         inv.r <- try(solve(r),silent=TRUE)
-        if(class(inv.r)== as.character("try-error"))  {warning("The tenBerge based scoring could not invert the correlation matrix, regression scores found instead")
+        if(inherits(inv.r, as.character("try-error")))  {warning("The tenBerge based scoring could not invert the correlation matrix, regression scores found instead")
                                                       ev <- eigen(r)
       ev$values[ev$values < .Machine$double.eps] <- 100 * .Machine$double.eps
         r <- ev$vectors %*% diag(ev$values) %*% t(ev$vectors)
@@ -48,14 +54,19 @@
         },
 
  
-
-    "Harman" = { #Grice equation 10 -- 
-       m <- t(f)  %*% f  #factor intercorrelations
-       inv.m <- solve(m)
-       w <- f %*%inv.m  
-       },
        
-    "Anderson" =  { #scores for orthogonal factor solution will be orthogonal
+       "Harman" = { #Grice equation 10 -- 
+     #   m <- t(f)  %*% f  #factor intercorrelations 
+     m <- f %*% t(S)  #should be this  (the model matrix)  Revised August 31, 2017
+     diag(m) <- 1  #Grice does not say this, but it is necessary to make it work!
+       inv.m <- solve(m)
+     #  w <- f %*%inv.m  
+     w <- inv.m %*% f
+       }, 
+       
+       
+        
+    "Anderson" =  { #scores for orthogonal factor solution will be orthogonal  Grice Eq 7 and 8
     I <- diag(1,nf,nf)
     h2 <-  diag( f %*% Phi %*% t(f))
     U2 <- 1 - h2
@@ -65,7 +76,7 @@
     rownames(w) <- rownames(f)
     },
     
-   "Bartlett" = {
+   "Bartlett" = {    #Grice eq 9  # f should be the pattern, not the structure 
     I <- diag(1,nf,nf)
     h2 <-  diag( f %*% Phi %*% t(f))
     U2 <- 1 - h2
@@ -81,26 +92,27 @@
     )
     
     
-    
     #now find a few fit statistics
     if(is.null(w)) {results <- list(scores=NULL,weights=NULL)} else {
-     R2 <- diag(t(w) %*% f)
-     if(any(R2>1) || (prod(!is.nan(R2)) <1) || (prod(R2) < 0) ) {#message("The matrix is probably singular -- Factor score estimate results are likely incorrect")
+     R2 <- diag(t(w) %*% S)  #this had been   R2 <- diag(t(w) %*% f)   Corrected Sept 1, 2017
+     if(any(R2 > 1) || (prod(!is.nan(R2)) <1) || (prod(R2) < 0) ) {#message("The matrix is probably singular -- Factor score estimate results are likely incorrect")
                       R2[abs(R2) > 1] <- NA
                       R2[R2 <= 0] <- NA
                      }
      #if ((max(R2,na.rm=TRUE) > (1 + .Machine$double.eps)) ) {message("The estimated weights for the factor scores are probably incorrect.  Try a different factor extraction method.")}
-      r.scores <- cov2cor(t(w) %*% r %*% w) 
+      r.scores <- cov2cor(t(w) %*% r %*% w) #what actually is this?
      
     
-  if(square) {
+  if(square) {  #that is, if given the correlation matrix
      class(w) <- NULL
      results <- list(scores=NULL,weights=w)
       results$r.scores <- r.scores 
    	  results$R2 <- R2   #this is the multiple R2 of the scores with the factors
      } else {
-         missing <- rowSums(is.na(x))
-    if(impute !="none") {
+     
+
+         #missing <- rowSums(is.na(x))
+    if(missing && (impute !="none")) {
        x <- data.matrix(x)
         miss <- which(is.na(x),arr.ind=TRUE)
         if(impute=="mean") {
@@ -110,7 +122,9 @@
         	x[miss]<- item.med[miss[,2]]}   #this only works if items is a matrix
      }
       
-     if(method !="components") {scores <- scale(x) %*% w } else {  #standardize the data before doing the regression if using factors, 
+     if(method !="components") {if(impute!="none")  {scores <- factorScoresSapa(weights=w,  items = scale(x))} else {
+    
+     scores <- scale(x) %*% w }} else {  #standardize the data before doing the regression if using factors, 
         scores <- x %*% w}       # for components, the data have already been zero centered and, if appropriate, scaled
      results <- list(scores=scores,weights=w)
      results$r.scores <- r.scores
