@@ -136,8 +136,8 @@ r <- cor(x[1:(n.obs-lag)],x[(lag+1):n.obs],use=use)
 x <- as.matrix(x)
 n <- colSums(!is.na(x))
 mssd <- colSums(diff(x,lag=lag,na.rm=na.rm)^2,na.rm=na.rm)/(n-lag)
-v1 <- apply(x[1:(n.obs-lag),],2,sd, na.rm=na.rm)^2
-v2 <- apply(x[(lag+1):n.obs,],2, sd,na.rm=na.rm)^2
+v1 <- apply(x[1:(n.obs-lag),,drop=FALSE],2,sd, na.rm=na.rm)^2
+v2 <- apply(x[(lag+1):n.obs,,drop=FALSE],2, sd,na.rm=na.rm)^2
 # r <- -(mssd - v1 - v2)/(2*sqrt(v1*v2))
 r <- diag(cor(x[1:(n.obs-lag),],x[(lag+1):n.obs,],use=use))
  result <- list(autoR = r,rssd=sqrt(mssd))
@@ -169,6 +169,8 @@ return(result)}
 
 
 
+
+
 #####
 sim.mssd <- function(n,r,g=.1) {
 rw <- rnorm(n,sqrt(1/(1-r^2)))
@@ -279,7 +281,7 @@ return(y)}
    rownames(f) <- ord
    if(!is.null(dictionary))  { 
    contents <- lookup(rownames(f),dictionary)} else {message("fa.lookup requires a dictionary, otherwise just use fa.sort")}
-   if(!is.null(h2)) {results <- data.frame(round(unclass(f),digits=digits),com=round(com,digits=digits),h2=round(h2,digits=digits))} else {
+   if(!is.null(h2)) {results <- data.frame(round(unclass(f),digits=digits),h2=round(h2,digits=digits),com=round(com,digits=digits))} else {
    results <- data.frame(round(unclass(f),digits=digits))}
    
    results <- merge(results,contents,by="row.names",all.x=TRUE,sort=FALSE)
@@ -406,11 +408,12 @@ if(is.null(names(fa.results)) )  {temp <- fa.results   #the matrix form
   
   "item.lookup" <- 
 function (f,m, dictionary,cut=.3, digits = 2) {
-    f <- fa.sort(f)
+   # f <- fa.sort(f)
     none<- NULL   #A strange requirement of R 4.0
      if(length(class(f)) > 1){ obnames <- cs(omega, fa, principal, iclust, none)
      value <- inherits(f, obnames, which=TRUE)
-			   if (any(value > 1)) {value <- obnames[which(value >0)]} else {value <- "none"}} else {value <- "none"}
+			   if (any(value > 1)) {value <- obnames[which(value >0)]} else {value <- "none"}
+			   f <- fa.sort(f) } else {value <- "none"}
   old.names <- NULL
    switch(value,
     
@@ -444,7 +447,7 @@ function (f,m, dictionary,cut=.3, digits = 2) {
         ord <- rownames(f)
         nfact <- ncol(f)
     }
-    means <- m[ord]
+    means <- m[ord]   #incorrectly added a comma to allow it sort dataframes 6/22/21
     f <- data.frame(unclass(f),means=means)
 
     contents <- lookup(rownames(f), y=dictionary)
@@ -650,11 +653,13 @@ pretty}
 
 #this just shows if it is a matrix is symmetric and has diagonals of 1
 #Added the unclass to  handle a problem with class partial.r  4/10/21
-"isCorrelation" <-  function(x) {value <- FALSE
+"isCorrelation" <-  function(x,na.rm=FALSE) {value <- FALSE
   if(NROW(x) == NCOL(x)) {
-  if( is.data.frame(x)) {if(isSymmetric(unclass(unname(as.matrix(x))))) { value <- TRUE}} else {if(isSymmetric(unclass(unname(x)))) {value <- TRUE}}}
+  if( is.data.frame(x)) {if(isSymmetric(unclass(unname(as.matrix(x))))) { value <- TRUE}} else {if(isSymmetric(unclass(unname(x)))) {value <- TRUE}}
   value <- value && isTRUE(all.equal(prod(diag(as.matrix(x))),1) )
+  if(!value  && (na.rm) && any(is.na(diag(as.matrix(x))))) stop("Although the matrix is symmetric, one of the elements of the  diagonal is NA. Check your data.")
   value <- value && isTRUE((min(x,na.rm=TRUE)>= -1) & (max(x,na.rm=TRUE) <= 1))  
+  }
   return(value)}
   
   #this just shows if it is a symmetric matrix
@@ -688,18 +693,19 @@ flip <- function(R,key) {#reverse correlations with keys  < 0
 	R[,key<0] <- -R[,key < 0]
   return(R)}
     
-
- matMult <- function(A,B) {  #matrix multiplication without matrices!  
-  nvar1 <- ncol(A)
-  nvar2 <- ncol(B)
-  M <- matrix(NA,ncol=nvar1,nrow=nrow(B))
-    if(nrow(A) != nvar2) {stop("incompatible dimensions")}
-   for(i in 1:nvar1) {
-    for (j in 1:nrow(B))  {
-    M[j,i] <-  sum(A[,i] * B[j,], na.rm=TRUE)
+#do matrix multiplication with missing values
+ matMult <- function(x,y) {  #matrix multiplication without matrices!  
+  nvar1 <- NCOL(x)
+  nvar2 <- NROW(y)
+  M <- matrix(NA,ncol =NCOL(y),nrow=NROW(x))
+    if(NCOL(x) != NROW(y)) {stop("incompatible dimensions")}
+   for(i in 1:NROW(x)) {
+    for (j in 1:NCOL(y))  {
+    M[i,j] <-  sum(x[i,] * y[,j], na.rm=TRUE)
     } 
     }
-    return(M)}
+    return(M)
+    }
      
    
    
@@ -713,6 +719,31 @@ flip <- function(R,key) {#reverse correlations with keys  < 0
            
     scores[,factors] <-t(colMeans( weights[,factors] * titem,  na.rm=TRUE))
     }
+    scores<- scale(scores)  #return standardized values
     return(scores)
   }
 
+countBad <- function(r.list) {
+n <- length(r.list)
+count <- 0
+for (i in 1:n) {
+ ev <-eigen(r.list[[i]])
+ bad <- any(ev$values < 0)
+ count <- count + bad}
+ return(count)
+ }
+
+#Create SAPA data by sampling
+SAPAfy <- function(x,y)
+{
+  n_vars <- ncol(x)
+  n_questions_unanswered <- round(n_vars - y)  #  in case someone inputs a double.
+  
+  for (xxx in 1:nrow(x)) 
+  {
+    x[xxx, sample.int(n_vars, n_questions_unanswered)  ] <- NA 
+  }
+  return(x)
+}
+
+
