@@ -1,5 +1,5 @@
 #modified 6/6/20 to vectorize the labels and rectangles.
-
+#modified 8/19/22 to make labels characters (which they are normally)
 "iclust.diagram" <- 
 function(ic,labels=NULL,short=FALSE,digits=2,cex=NULL,min.size=NULL,e.size=1,colors=c("black","blue"), main="ICLUST diagram",cluster.names = NULL,marg=c(.5,.5,1.5,.5)) {
 
@@ -16,7 +16,8 @@ if(is.null(cex)) cex <- min(16/num.var,1)
     	var.labels <- rownames(ic$loadings)} else {var.labels=labels}
     if (short) {var.labels <- paste("V",1:num.var,sep="")} 
   if(is.null(var.labels)) {var.labels <- paste("V",1:num.var,sep="")} 
-
+ 	
+ 	var.labels <- as.character(var.labels)  #added 8/19/22
 fixed <- fix.names(ic,var.labels)
 clusters <- fixed$ic$results
 max.len <- max(nchar((var.labels)))
@@ -32,7 +33,10 @@ nvar <- sum(ic$size)
 last <- dim(clusters)[1]
 max.size <- max(ic$size)
 
-limx <- c(-length.labels,nvar+2)
+#limx <- c(-length.labels,nvar+2)  #for long names and not many variables this is ugly
+
+if(nvar < 12) {limx <- c(-max.len*.08 * cex,nvar+2)} else {limx <- c(-length.labels,nvar+2)}  #for long names and not many variables this is ugly
+
 limy <-  c(0,nvar+1)
 if(nvar < 12) e.size <- e.size * .7   #this is a kludge to make small problems look better
 
@@ -116,6 +120,7 @@ text(tv[,1],tv[,2],tv[,3],cex=tv[,5])
 
  fix.names <- function(ic,var.labels) {
  	var.names <- ic$results[,c(1:2)]
+
 	max.len <- 0
 	vn <- dim(var.names)[1]
 	for(i in 1:vn) {
@@ -173,6 +178,7 @@ text(tv[,1],tv[,2],tv[,3],cex=tv[,5])
   #this draws all the clusters at once 
   #still a little slow, but better than before
   # By putting NA at the end of every unit.circle, we can draw multiple circles rapidly
+  #modified 8/21/22 to include "beta"
  "dia.cluster1" <- 
  function(cluster.df,digits=2,cex = cex,e.size=.6,xlim=c(0,1),ylim=c(0,1)) {
  
@@ -189,12 +195,13 @@ text(tv[,1],tv[,2],tv[,3],cex=tv[,5])
 	 #these next two lines just report the first values
 	 temp.alpha <- substitute(list(alpha) == "")
 	 temp.beta <- substitute(list(beta) == "")
-	 text(x.big,y.big,temp.alpha,cex=cex,adj=1)
-	# text(x.big,y.big,temp.beta, cex=cex,pos=1)
-	 
+	 text(x.big,y.big,temp.alpha,cex=cex,adj=1)  #this shows the symbol alpha to the left
+	 text(x.big,y.big,temp.beta, cex=cex,adj=c(1,1.5))  #below and to the left 
+	
 	 text(x.big,y.big,round(big[,"alpha"],digits),offset=1,adj=0,cex=cex)
-	 	 text(x.big,y.big,round(big[,"beta"],digits),cex=cex,pos=1)
-
+	 #	 text(x.big,y.big,round(big[,"beta"],digits),cex=cex,pos=1)
+     #text(x.big,y.big,round(big[,"beta"],digits),cex=cex,pos=1)
+          text(x.big,y.big,round(big[,"beta"],digits),cex=cex,adj=c(0,1.7))
 	 #text(x.big,y.big, substitute(list(alpha) == list(a),list(a=round(big[,"alpha"],digits))),cex=cex) 
 	 #text(x.big,y.big, substitute(list(beta) == list(b), list(b=round(big[,"beta"],digits))),cex=cex,pos=1) 
 	# temp.n <- NROW(big)
