@@ -1,5 +1,5 @@
 "omegah" <-
-function(m,nfactors=3,fm="minres",key=NULL,flip=TRUE, digits=2,title="Omega",sl=TRUE,labels=NULL, plot=TRUE,n.obs=NA,rotate="oblimin",Phi = NULL,option="equal",covar=FALSE,...) {
+function(m,nfactors=3,fm="minres",key=NULL,flip=TRUE, digits=2,title="Omega",sl=TRUE,labels=NULL, plot=TRUE,n.obs=NA,rotate="oblimin",Phi = NULL,option="equal",covar=FALSE,two.ok=FALSE,...) {
       #m is a correlation matrix, or if not, the correlation matrix is found
       #nfactors is the number of factors to extract
       #key allows items to be reversed scored  if desired
@@ -9,7 +9,7 @@ function(m,nfactors=3,fm="minres",key=NULL,flip=TRUE, digits=2,title="Omega",sl=
       nvar <- dim(m)[2]
       raw.data <- NULL
       if(is.null(Phi)) {   #the normal case is to do the factor analysis of the raw data or the correlation matrix
-      if(!isCorrelation(m)) {
+      if(!isCorrelation(m)) {   #should also check for covariance matrix
                             n.obs <- dim(m)[1]
                             m <- as.matrix(m)
                             raw.data <- m #added 9/1/14
@@ -33,7 +33,7 @@ function(m,nfactors=3,fm="minres",key=NULL,flip=TRUE, digits=2,title="Omega",sl=
        fm <- "minres"} 
        } else { m.names <- rownames(m) }   #add the names if we have a factor input 
        
-      gf <-schmid(m,nfactors,fm,digits,rotate=rotate,n.obs=n.obs,Phi=Phi,option=option,covar=covar, ...)
+      gf <-schmid(m,nfactors,fm,digits,rotate=rotate,n.obs=n.obs,Phi=Phi,option=option,covar=covar,two.ok=two.ok, ...)
       if(!is.null(Phi)) { model <- m
                           nfactors <- dim(model)[2]
                           m <- factor.model(model,Phi=Phi,U2=FALSE)  #estimate the correlation matrix from the factor model
@@ -109,7 +109,7 @@ function(m,nfactors=3,fm="minres",key=NULL,flip=TRUE, digits=2,title="Omega",sl=
   #we should standardize the raw.data before doing the next step
      if(!is.null(raw.data)) {scores <- raw.data %*%  omega.stats$weights} else {scores<- NULL} 
     # }
-     omega <- list(omega_h= gsq/Vt,omega.lim = om.limit,alpha=alpha,omega.tot=om.tot,G6=lambda.6,schmid=gf,key=key,stats = omega.stats,ECV=ECV,gstats = general.stats,call=cl,title=title,R = m,model=omega.model,omega.group=om.group,scores=scores)
+     omega <- list(omega_h= gsq/Vt,omega.lim = om.limit,alpha=alpha,omega.tot=om.tot,G6=lambda.6,schmid=gf,key=key,stats = omega.stats,ECV=ECV,gstats = general.stats,call=cl,title=title,R = m,model=omega.model,omega.group=om.group,scores=scores,Call=cl)
 
       class(omega) <- c("psych","omega")
      if(plot)  omega.diagram(omega,main=title,sl=sl,labels=labels,digits=dg)
@@ -122,7 +122,7 @@ function(m,nfactors=3,fm="minres",key=NULL,flip=TRUE, digits=2,title="Omega",sl=
 "omega" <- 
 function(m,nfactors=3,fm="minres",n.iter=1,p=.05,poly=FALSE,key=NULL,flip=TRUE, digits=2,title="Omega",sl=TRUE,labels=NULL, plot=TRUE,n.obs=NA,rotate="oblimin",Phi = NULL,option="equal",covar=FALSE,...) {
  cl <- match.call()
-  if(is.data.frame(m) || is.matrix(m)) {if(isCorrelation(m)) {if(is.na(n.obs) && (n.iter > 1)) stop("You must specify the number of subjects if giving a correlation matrix")
+  if(is.data.frame(m) || is.matrix(m)) {if((isCorrelation(m)) | (isCovariance(m) && covar)) {if(is.na(n.obs) && (n.iter > 1)) stop("You must specify the number of subjects if giving a correlation matrix")
                                 # if(!require(MASS)) stop("You must have MASS installed to simulate data from a correlation matrix")
                                  }
                   }
@@ -175,7 +175,7 @@ rownames(ci) <- c("omega_h","alpha","omega_tot","G6","omega_lim")
 colnames(replicates) <- names(means) <- names(sds) <- rownames(ci) 
 conf <- list(means = means,sds = sds,ci = ci,Call= cl,replicates=replicates)
 om$Call=cl
-results <- list(om = om,ci=conf) } else {om$call=cl
+results <- list(om = om,ci=conf) } else {om$Call=cl
                                          if(poly) {om$rho <- pol$rho
                                                    om$tau <- pol$tau
                                                    om$n.obs <- pol$n.obs
